==> react-bootstrap-0.2.0.tgz: package/es/components/ButtonWithDropdown/index.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp2;

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import cn from 'classnames';

import Button from '../Button';

var ButtonWithDropdown = (_temp2 = _class = function (_Component) {
  _inherits(ButtonWithDropdown, _Component);

  function ButtonWithDropdown() {
    var _temp, _this, _ret;

    _classCallCheck(this, ButtonWithDropdown);

    for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return _ret = (_temp = (_this = _possibleConstructorReturn(this, _Component.call.apply(_Component, [this].concat(args))), _this), _this.state = {
      showDropdown: false
    }, _this.onToggle = function (e) {
      _this.toggleDropdown();
      _this.props.onToggle(e);
    }, _this.toggleDropdown = function () {
      return _this.setState({
        showDropdown: !_this.state.showDropdown
      }, _this.toggleEventListener);
    }, _this.toggleEventListener = function () {
      return _this.state.showDropdown ? document.addEventListener('click', _this.handleClick) : document.removeEventListener('click', _this.handleClick);
    }, _this.handleClick = function (e) {
      return _this.dropdown && !_this.dropdown.contains(e.target) && _this.toggleDropdown();
    }, _temp), _possibleConstructorReturn(_this, _ret);
  }

  ButtonWithDropdown.prototype.render = function render() {
    var _this2 = this;

    var _props = this.props,
        dropdown = _props.dropdown,
        className = _props.className,
        onClick = _props.onClick,
        onToggle = _props.onToggle,
        children = _props.children,
        props = _objectWithoutProperties(_props, ['dropdown', 'className', 'onClick', 'onToggle', 'children']);

    var showDropdown = this.state.showDropdown;


    return React.createElement(
      Button.Group,
      { className: className },
      React.createElement(
        Button,
        _extends({}, props, {
          className: cn('dropdown-toggle', { 'dropdown-toggle-split': !children }),
          onClick: this.onToggle
        }),
        children
      ),
      React.createElement(
        'div',
        {
          className: cn('dropdown-menu', { show: showDropdown }),
          ref: function ref(node) {
            _this2.dropdown = node;
          }
        },
        typeof dropdown === 'function' ? dropdown(this.toggleDropdown) : dropdown
      )
    );
  };

  return ButtonWithDropdown;
}(Component), _class.defaultProps = {
  dropdown: null,
  className: '',
  onClick: function onClick() {},
  onToggle: function onToggle() {},
  children: null
}, _temp2);
ButtonWithDropdown.propTypes = process.env.NODE_ENV !== "production" ? {
  dropdown: PropTypes.oneOfType([PropTypes.string, PropTypes.node, PropTypes.func]),
  className: PropTypes.string,
  onClick: PropTypes.func,
  onToggle: PropTypes.func,
  children: PropTypes.node
} : {};


export default ButtonWithDropdown;

==> react-bootstrap-0.2.2.tgz: package/es/components/ButtonWithDropdown/index.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp2;

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import cn from 'classnames';

import Button from '../Button';

var ButtonWithDropdown = (_temp2 = _class = function (_Component) {
  _inherits(ButtonWithDropdown, _Component);

  function ButtonWithDropdown() {
    var _temp, _this, _ret;

    _classCallCheck(this, ButtonWithDropdown);

    for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return _ret = (_temp = (_this = _possibleConstructorReturn(this, _Component.call.apply(_Component, [this].concat(args))), _this), _this.state = {
      showDropdown: false
    }, _this.onToggle = function (e) {
      _this.toggleDropdown();
      _this.props.onToggle(e);
    }, _this.toggleDropdown = function () {
      return _this.setState(function (state) {
        return { showDropdown: !state.showDropdown };
      }, _this.toggleEventListener);
    }, _this.toggleEventListener = function () {
      return _this.state.showDropdown ? document.addEventListener('click', _this.handleClick) : document.removeEventListener('click', _this.handleClick);
    }, _this.handleClick = function (e) {
      return _this.dropdown && !_this.dropdown.contains(e.target) && _this.toggleDropdown();
    }, _temp), _possibleConstructorReturn(_this, _ret);
  }

  ButtonWithDropdown.prototype.render = function render() {
    var _this2 = this;

    var _props = this.props,
        dropdown = _props.dropdown,
        className = _props.className,
        onClick = _props.onClick,
        onToggle = _props.onToggle,
        children = _props.children,
        props = _objectWithoutProperties(_props, ['dropdown', 'className', 'onClick', 'onToggle', 'children']);

    var showDropdown = this.state.showDropdown;


    return React.createElement(
      Button.Group,
      { className: className },
      React.createElement(
        Button,
        _extends({}, props, {
          className: cn('dropdown-toggle', { 'dropdown-toggle-split': !children }),
          onClick: this.onToggle
        }),
        children
      ),
      React.createElement(
        'div',
        {
          className: cn('dropdown-menu', { show: showDropdown }),
          ref: function ref(node) {
            _this2.dropdown = node;
          }
        },
        typeof dropdown === 'function' ? dropdown(this.toggleDropdown) : dropdown
      )
    );
  };

  return ButtonWithDropdown;
}(Component), _class.defaultProps = {
  dropdown: null,
  className: '',
  onClick: function onClick() {},
  onToggle: function onToggle() {},
  children: null
}, _temp2);
ButtonWithDropdown.propTypes = process.env.NODE_ENV !== "production" ? {
  dropdown: PropTypes.oneOfType([PropTypes.string, PropTypes.node, PropTypes.func]),
  className: PropTypes.string,
  onClick: PropTypes.func,
  onToggle: PropTypes.func,
  children: PropTypes.node
} : {};


export default ButtonWithDropdown;
